==> jc-1.4.0.tar.gz: gnu/java/net/protocol/http/SimpleCookieManager.h <==
// public class gnu.java.net.protocol.http.SimpleCookieManager

// class file dependencies
// @dep_class 3c1c1a9edc3abdac gnu_java_net_protocol_http_SimpleCookieManager
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_java_net_protocol_http_SimpleCookieManager_H_
#define _JC_gnu_java_net_protocol_http_SimpleCookieManager_H_

// Forward structure declarations
struct _jc_gnu_java_net_protocol_http_Cookie$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Date$object;
struct _jc_java_util_List$object;
struct _jc_java_util_Map$object;

// Typedefs
typedef struct _jc_gnu_java_net_protocol_http_SimpleCookieManager$sub_refs	_jc_gnu_java_net_protocol_http_SimpleCookieManager$sub_refs;
typedef struct _jc_gnu_java_net_protocol_http_SimpleCookieManager$sub_nonrefs	_jc_gnu_java_net_protocol_http_SimpleCookieManager$sub_nonrefs;
typedef struct _jc_gnu_java_net_protocol_http_SimpleCookieManager$refs	_jc_gnu_java_net_protocol_http_SimpleCookieManager$refs;
typedef struct _jc_gnu_java_net_protocol_http_SimpleCookieManager$nonrefs	_jc_gnu_java_net_protocol_http_SimpleCookieManager$nonrefs;
typedef struct _jc_gnu_java_net_protocol_http_SimpleCookieManager$object	_jc_gnu_java_net_protocol_http_SimpleCookieManager$object;

typedef const struct _jc_gnu_java_net_protocol_http_SimpleCookieManager$vmethods	_jc_gnu_java_net_protocol_http_SimpleCookieManager$vmethods;
typedef const struct _jc_gnu_java_net_protocol_http_SimpleCookieManager$vtable	_jc_gnu_java_net_protocol_http_SimpleCookieManager$vtable;
typedef const struct _jc_gnu_java_net_protocol_http_SimpleCookieManager$vtype	_jc_gnu_java_net_protocol_http_SimpleCookieManager$vtype;

// Constructors
extern void _jc_gnu_java_net_protocol_http_SimpleCookieManager$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_java_net_protocol_http_SimpleCookieManager$object *);

// Virtual methods
extern void _jc_gnu_java_net_protocol_http_SimpleCookieManager$method$addCookies$459c2422897ac01b(_jc_env *, struct _jc_gnu_java_net_protocol_http_SimpleCookieManager$object *, struct _jc_object *, struct _jc_java_lang_String$object *, jboolean, struct _jc_java_lang_String$object *, struct _jc_java_util_Date$object *);
extern _jc_object_array *_jc_gnu_java_net_protocol_http_SimpleCookieManager$method$getCookies$78792005b97c8302(_jc_env *, struct _jc_gnu_java_net_protocol_http_SimpleCookieManager$object *, struct _jc_java_lang_String$object *, jboolean, struct _jc_java_lang_String$object *);
extern void _jc_gnu_java_net_protocol_http_SimpleCookieManager$method$setCookie$5925dd013023fb6b(_jc_env *, struct _jc_gnu_java_net_protocol_http_SimpleCookieManager$object *, struct _jc_gnu_java_net_protocol_http_Cookie$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_net_protocol_http_SimpleCookieManager$method_info$addCookies$459c2422897ac01b;
extern _jc_method _jc_gnu_java_net_protocol_http_SimpleCookieManager$method_info$getCookies$78792005b97c8302;
extern _jc_method _jc_gnu_java_net_protocol_http_SimpleCookieManager$method_info$setCookie$5925dd013023fb6b;

// Virtual methods structure
struct _jc_gnu_java_net_protocol_http_SimpleCookieManager$vmethods {
	void	(*addCookies$459c2422897ac01b)(_jc_env *, struct _jc_gnu_java_net_protocol_http_SimpleCookieManager$object *, struct _jc_object *, struct _jc_java_lang_String$object *, jboolean, struct _jc_java_lang_String$object *, struct _jc_java_util_Date$object *);
	_jc_object_array	*(*getCookies$78792005b97c8302)(_jc_env *, struct _jc_gnu_java_net_protocol_http_SimpleCookieManager$object *, struct _jc_java_lang_String$object *, jboolean, struct _jc_java_lang_String$object *);
	void	(*setCookie$5925dd013023fb6b)(_jc_env *, struct _jc_gnu_java_net_protocol_http_SimpleCookieManager$object *, struct _jc_gnu_java_net_protocol_http_Cookie$object *);
};

// Vtable
struct _jc_gnu_java_net_protocol_http_SimpleCookieManager$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_net_protocol_http_SimpleCookieManager$vmethods	gnu_java_net_protocol_http_SimpleCookieManager;
};

// Vtype
struct _jc_gnu_java_net_protocol_http_SimpleCookieManager$vtype {
	_jc_type			type;
	_jc_gnu_java_net_protocol_http_SimpleCookieManager$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_net_protocol_http_SimpleCookieManager$sub_refs {
	struct _jc_object	*cookies;
};

// Reference instance fields (object)
struct _jc_gnu_java_net_protocol_http_SimpleCookieManager$refs {
    _jc_gnu_java_net_protocol_http_SimpleCookieManager$sub_refs	gnu_java_net_protocol_http_SimpleCookieManager;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_net_protocol_http_SimpleCookieManager$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_net_protocol_http_SimpleCookieManager$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_net_protocol_http_SimpleCookieManager$sub_nonrefs	gnu_java_net_protocol_http_SimpleCookieManager;
};

// Object instance structure
struct _jc_gnu_java_net_protocol_http_SimpleCookieManager$object {
	_jc_gnu_java_net_protocol_http_SimpleCookieManager$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_net_protocol_http_SimpleCookieManager$vtype	*vtype;
	_jc_gnu_java_net_protocol_http_SimpleCookieManager$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_net_protocol_http_SimpleCookieManager$vtype _jc_gnu_java_net_protocol_http_SimpleCookieManager$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_net_protocol_http_SimpleCookieManager, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_net_protocol_http_SimpleCookieManager$class_object;

#endif	/* _JC_gnu_java_net_protocol_http_SimpleCookieManager_H_ */

==> jc-1.4.6.tar.gz: gnu/java/net/protocol/http/SimpleCookieManager.h <==
// public class gnu.java.net.protocol.http.SimpleCookieManager

// class file dependencies
// @dep_class 3c1c1a9edc3abdac gnu_java_net_protocol_http_SimpleCookieManager
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_java_net_protocol_http_SimpleCookieManager_H_
#define _JC_gnu_java_net_protocol_http_SimpleCookieManager_H_

// Forward structure declarations
struct _jc_gnu_java_net_protocol_http_Cookie$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Date$object;
struct _jc_java_util_List$object;
struct _jc_java_util_Map$object;

// Typedefs
typedef struct _jc_gnu_java_net_protocol_http_SimpleCookieManager$sub_refs	_jc_gnu_java_net_protocol_http_SimpleCookieManager$sub_refs;
typedef struct _jc_gnu_java_net_protocol_http_SimpleCookieManager$sub_nonrefs	_jc_gnu_java_net_protocol_http_SimpleCookieManager$sub_nonrefs;
typedef struct _jc_gnu_java_net_protocol_http_SimpleCookieManager$refs	_jc_gnu_java_net_protocol_http_SimpleCookieManager$refs;
typedef struct _jc_gnu_java_net_protocol_http_SimpleCookieManager$nonrefs	_jc_gnu_java_net_protocol_http_SimpleCookieManager$nonrefs;
typedef struct _jc_gnu_java_net_protocol_http_SimpleCookieManager$object	_jc_gnu_java_net_protocol_http_SimpleCookieManager$object;

typedef const struct _jc_gnu_java_net_protocol_http_SimpleCookieManager$vmethods	_jc_gnu_java_net_protocol_http_SimpleCookieManager$vmethods;
typedef const struct _jc_gnu_java_net_protocol_http_SimpleCookieManager$vtable	_jc_gnu_java_net_protocol_http_SimpleCookieManager$vtable;
typedef const struct _jc_gnu_java_net_protocol_http_SimpleCookieManager$vtype	_jc_gnu_java_net_protocol_http_SimpleCookieManager$vtype;

// Constructors
extern void _jc_gnu_java_net_protocol_http_SimpleCookieManager$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_java_net_protocol_http_SimpleCookieManager$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_gnu_java_net_protocol_http_SimpleCookieManager$method$addCookies$459c2422897ac01b(_jc_env *, struct _jc_gnu_java_net_protocol_http_SimpleCookieManager$object *, struct _jc_object *, struct _jc_java_lang_String$object *, jboolean, struct _jc_java_lang_String$object *, struct _jc_java_util_Date$object *) _JC_JCNI_ATTR;
extern _jc_object_array *_jc_gnu_java_net_protocol_http_SimpleCookieManager$method$getCookies$78792005b97c8302(_jc_env *, struct _jc_gnu_java_net_protocol_http_SimpleCookieManager$object *, struct _jc_java_lang_String$object *, jboolean, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_java_net_protocol_http_SimpleCookieManager$method$setCookie$5925dd013023fb6b(_jc_env *, struct _jc_gnu_java_net_protocol_http_SimpleCookieManager$object *, struct _jc_gnu_java_net_protocol_http_Cookie$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_net_protocol_http_SimpleCookieManager$method_info$addCookies$459c2422897ac01b;
extern _jc_method _jc_gnu_java_net_protocol_http_SimpleCookieManager$method_info$getCookies$78792005b97c8302;
extern _jc_method _jc_gnu_java_net_protocol_http_SimpleCookieManager$method_info$setCookie$5925dd013023fb6b;

// Virtual methods structure
struct _jc_gnu_java_net_protocol_http_SimpleCookieManager$vmethods {
	void	(*addCookies$459c2422897ac01b)(_jc_env *, struct _jc_gnu_java_net_protocol_http_SimpleCookieManager$object *, struct _jc_object *, struct _jc_java_lang_String$object *, jboolean, struct _jc_java_lang_String$object *, struct _jc_java_util_Date$object *) _JC_JCNI_ATTR;
	_jc_object_array	*(*getCookies$78792005b97c8302)(_jc_env *, struct _jc_gnu_java_net_protocol_http_SimpleCookieManager$object *, struct _jc_java_lang_String$object *, jboolean, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
	void	(*setCookie$5925dd013023fb6b)(_jc_env *, struct _jc_gnu_java_net_protocol_http_SimpleCookieManager$object *, struct _jc_gnu_java_net_protocol_http_Cookie$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_net_protocol_http_SimpleCookieManager$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_net_protocol_http_SimpleCookieManager$vmethods	gnu_java_net_protocol_http_SimpleCookieManager;
};

// Vtype
struct _jc_gnu_java_net_protocol_http_SimpleCookieManager$vtype {
	_jc_type			type;
	_jc_gnu_java_net_protocol_http_SimpleCookieManager$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_net_protocol_http_SimpleCookieManager$sub_refs {
	struct _jc_object	*cookies;
};

// Reference instance fields (object)
struct _jc_gnu_java_net_protocol_http_SimpleCookieManager$refs {
    _jc_gnu_java_net_protocol_http_SimpleCookieManager$sub_refs	gnu_java_net_protocol_http_SimpleCookieManager;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_net_protocol_http_SimpleCookieManager$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_net_protocol_http_SimpleCookieManager$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_net_protocol_http_SimpleCookieManager$sub_nonrefs	gnu_java_net_protocol_http_SimpleCookieManager;
};

// Object instance structure
struct _jc_gnu_java_net_protocol_http_SimpleCookieManager$object {
	_jc_gnu_java_net_protocol_http_SimpleCookieManager$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_net_protocol_http_SimpleCookieManager$vtype	*vtype;
	_jc_gnu_java_net_protocol_http_SimpleCookieManager$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_net_protocol_http_SimpleCookieManager$vtype _jc_gnu_java_net_protocol_http_SimpleCookieManager$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_net_protocol_http_SimpleCookieManager, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_net_protocol_http_SimpleCookieManager$class_object;

#endif	/* _JC_gnu_java_net_protocol_http_SimpleCookieManager_H_ */
